@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2012-2014 Steven Myint
+# Copyright (C) 2012-2015 Steven Myint
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -41,7 +41,7 @@ import tokenize
 import untokenize
 
 
-__version__ = '0.7'
+__version__ = '0.8'
 
 
 try:
@@ -68,6 +68,7 @@ def _format_code(source,
                  summary_wrap_length=79,
                  description_wrap_length=72,
                  pre_summary_newline=False,
+                 make_summary_multi_line=False,
                  post_description_blank=True,
                  force_wrap=False,
                  line_range=None):
@@ -116,6 +117,7 @@ def _format_code(source,
                 summary_wrap_length=summary_wrap_length,
                 description_wrap_length=description_wrap_length,
                 pre_summary_newline=pre_summary_newline,
+                make_summary_multi_line=make_summary_multi_line,
                 post_description_blank=post_description_blank,
                 force_wrap=force_wrap)
 
@@ -135,6 +137,7 @@ def format_docstring(indentation, docstring,
                      summary_wrap_length=0,
                      description_wrap_length=0,
                      pre_summary_newline=False,
+                     make_summary_multi_line=False,
                      post_description_blank=True,
                      force_wrap=False):
     """Return formatted version of docstring.
@@ -199,10 +202,24 @@ def format_docstring(indentation, docstring,
             post_description=('\n' if post_description_blank else ''),
             indentation=indentation)
     else:
-        return wrap_summary('"""' + normalize_summary(contents) + '"""',
-                            wrap_length=summary_wrap_length,
-                            initial_indent=indentation,
-                            subsequent_indent=indentation).strip()
+        if make_summary_multi_line:
+            beginning = '"""\n' + indentation
+            ending = '\n' + indentation + '"""'
+            summary_wrapped = wrap_summary(
+                normalize_summary(contents),
+                wrap_length=summary_wrap_length,
+                initial_indent=indentation,
+                subsequent_indent=indentation).strip()
+            return '{beginning}{summary}{ending}'.format(
+                beginning=beginning,
+                summary=summary_wrapped,
+                ending=ending
+            )
+        else:
+            return wrap_summary('"""' + normalize_summary(contents) + '"""',
+                                wrap_length=summary_wrap_length,
+                                initial_indent=indentation,
+                                subsequent_indent=indentation).strip()
 
 
 def reindent(text, indentation):
@@ -307,15 +324,26 @@ def split_first_sentence(text):
 def is_some_sort_of_list(text):
     """Return True if text looks like a list."""
     split_lines = text.rstrip().splitlines()
+
+    # Very large number of lines but short columns probably means a list of
+    # items.
     if len(split_lines) > max([len(line.strip()) for line in split_lines] +
                               [0]):
         return True
 
-    return (
-        re.search(r'\n\s*\n', text) or
-        re.search(r'[0-9]\.', text) or
-        re.search(r'[\-*:=@]', text)
-    )
+    for line in split_lines:
+        if (
+            re.match(r'\s*$', line) or
+            # "1. item"
+            re.match(r'\s*[0-9]\.', line) or
+            # "@parameter"
+            re.match(r'\s*[\-*:=@]', line) or
+            # "parameter - description"
+            re.match(r'.*\s+[\-*:=@]\s+', line)
+        ):
+            return True
+
+    return False
 
 
 def _find_shortest_indentation(lines):
@@ -494,6 +522,7 @@ def _format_code_with_args(source, args):
         summary_wrap_length=args.wrap_summaries,
         description_wrap_length=args.wrap_descriptions,
         pre_summary_newline=args.pre_summary_newline,
+        make_summary_multi_line=args.make_summary_multi_line,
         post_description_blank=args.post_description_blank,
         force_wrap=args.force_wrap,
         line_range=args.line_range)
@@ -522,6 +551,10 @@ def _main(argv, standard_out, standard_error, standard_in):
                         action='store_true',
                         help='add a newline before the summary of a '
                              'multi-line docstring')
+    parser.add_argument('--make-summary-multi-line',
+                        action='store_true',
+                        help='add a newline before and after the summary of a '
+                             'one-line docstring')
     parser.add_argument('--force-wrap', action='store_true',
                         help='force descriptions to be wrapped even if it may '
                              'result in a mess')
@@ -569,7 +602,7 @@ def _format_standard_in(args, parser, standard_out, standard_in):
     source = standard_in.read()
 
     if not isinstance(source, unicode):
-        encoding = standard_in.encoding or locale.getpreferredencoding()
+        encoding = standard_in.encoding or _get_encoding()
         source = source.decode(encoding)
 
     formatted_source = _format_code_with_args(source, args=args)
@@ -579,6 +612,11 @@ def _format_standard_in(args, parser, standard_out, standard_in):
     standard_out.write(formatted_source)
 
 
+def _get_encoding():
+    """Return preferred encoding."""
+    return locale.getpreferredencoding() or sys.getdefaultencoding()
+
+
 def _format_files(args, standard_out, standard_error):
     """Format multiple files."""
     filenames = list(set(args.files))
