@@ -10,14 +10,12 @@ from __future__ import (absolute_import,
 import contextlib
 import io
 import os
+import random
+import shutil
+import subprocess
 import sys
 import tempfile
-
-try:
-    # Python 2.6
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 import docformatter
 
@@ -319,7 +317,7 @@ Hello.
 '''
 """.strip()))
 
-    def test_format_docstring_with_single_quotes_multiline(self):
+    def test_format_docstring_with_single_quotes_multi_line(self):
         self.assertEqual('''
     """Return x factorial.
 
@@ -424,7 +422,7 @@ def f(x):
 def g(x):
     """  Badly indented docstring"""
     pass''',
-        docformatter.format_code('''\
+                         docformatter.format_code('''\
 def f(x):
     """  This is a docstring. That should be on more lines"""
     pass
@@ -444,7 +442,7 @@ def f(x):
 def g(x):
     """  Badly indented docstring"""
     pass''',
-        docformatter.format_code('''\
+                         docformatter.format_code('''\
 def f(x):
     """  This is a docstring. That should be on more lines"""
     pass
@@ -669,7 +667,7 @@ def foo():
     """
 '''))
 
-    def test_format_code_with_multiple_sentences_multiline_summary(self):
+    def test_format_code_with_multiple_sentences_multi_line_summary(self):
         self.assertEqual(
             '''\
 def foo():
@@ -1095,6 +1093,16 @@ num_iterations is the number of updates - instead of a better definition of conv
         self.assertFalse(docformatter.is_probably_beginning_of_sentence(
             '(this just continues an existing sentence).'))
 
+    def test_format_docstring_make_summary_multi_line(self):
+        self.assertEqual(('''\
+"""
+    This one-line docstring will be multi-line.
+    """\
+'''),
+                         docformatter.format_docstring('    ', '''\
+"""This one-line docstring will be multi-line"""\
+''', make_summary_multi_line=True))
+
 
 class TestSystem(unittest.TestCase):
 
@@ -1281,7 +1289,6 @@ def generate_random_docstring(max_indentation_length=32,
                               max_word_length=20,
                               max_words=50):
     """Generate single-line docstring."""
-    import random
     if random.randint(0, 1):
         words = []
     else:
@@ -1296,7 +1303,6 @@ def generate_random_docstring(max_indentation_length=32,
 
 
 def generate_random_word(word_length):
-    import random
     return ''.join(
         [random.choice('abcdefghijklmnoprstuvwyxzABCDEFGHIJKLMNOPRSTUVWXYZ')
          for _ in range(word_length)])
@@ -1312,7 +1318,6 @@ def temporary_file(contents, directory='.', prefix=''):
         f.close()
         yield f.name
     finally:
-        import os
         os.remove(f.name)
 
 
@@ -1323,7 +1328,6 @@ def temporary_directory(directory='.', prefix=''):
     try:
         yield temp_directory
     finally:
-        import shutil
         shutil.rmtree(temp_directory)
 
 
@@ -1336,11 +1340,8 @@ def run_docformatter(arguments):
     "untokenize".
 
     """
-    import os
     environ = os.environ.copy()
-    import sys
     environ['PYTHONPATH'] = os.pathsep.join(sys.path)
-    import subprocess
     return subprocess.Popen(DOCFORMATTER_COMMAND + arguments,
                             stdout=subprocess.PIPE,
                             stderr=subprocess.PIPE,
